# Hotsos

Use hotsos to implement repeatable analysis and extract useful information from common cloud applications and subsystems. Write analysis *Scenarios* in YAML using a high-level language and helpful Python libraries. A catalog of analysis implementations is included.

Hotsos is plugin-oriented, providing easy access to the state of applications and subsystems. Hotsos is run against a *Data Root* which can either be the host it is run on or a sosreport. Output is a summary of key information from each plugin along with issuses or known bugs detected and suggestions on what actions can be taken to handle them.

## Documentation

Installation and Usage: https://hotsos.readthedocs.io/en/latest/install/index.html

Contributing: https://hotsos.readthedocs.io/en/latest/contrib/index.html

Full documentation: https://hotsos.readthedocs.io/en/latest/
